@@ -14,7 +14,6 @@ import Options.Applicative
 import Text.Printf (printf)
 import System.Directory (canonicalizePath)
 import Control.Monad (unless)
-import Network.Wai.Middleware.Autohead
 import Network.Wai.Middleware.RequestLogger (logStdout)
 import Network.Wai.Middleware.Gzip
 import qualified Data.Map as Map
@@ -38,6 +37,12 @@ data Args = Args
     , host :: String
     }
 
+#if MIN_VERSION_optparse_applicative(0, 10, 0)
+option' = option auto
+#else
+option' = option
+#endif
+
 args :: Parser Args
 args = Args
     <$> strOption
@@ -52,7 +57,7 @@ args = Args
            <> metavar "INDEX"
            <> help "index files to serve when a directory is required"
             )))
-    <*> option
+    <*> option'
             ( long "port"
            <> short 'p'
            <> metavar "PORT"
@@ -94,7 +99,6 @@ runCommandLine middleware = do
     unless quiet $ printf "Serving directory %s on port %d with %s index files.\n" docroot' port (if noindex then "no" else show index)
     let middle = gzip def { gzipFiles = GzipCompress }
                . (if verbose then logStdout else id)
-               . autohead
                . (middleware args)
     runSettings defaultSettings
         { settingsPort = port
